From 0d778fcc4e489f541271fa25087777a9253d129e Mon Sep 17 00:00:00 2001
From: Ole Ostergaard <ole.c.ostergaard@gmail.com>
Date: Tue, 26 Feb 2019 14:08:55 +0100
Subject: Code cleanup.

Signed-off-by: Ole Ostergaard <ole.c.ostergaard@gmail.com>
---
 lib/public/IDBConnection.php | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

(limited to 'lib/public')

diff --git a/lib/public/IDBConnection.php b/lib/public/IDBConnection.php
index f640ec126f0..4c66896a2fe 100644
--- a/lib/public/IDBConnection.php
+++ b/lib/public/IDBConnection.php
@@ -128,11 +128,11 @@ interface IDBConnection {
 	 * Implementation is not fully finished and should not be used!
 	 *
 	 * @param string $table The table name (will replace *PREFIX* with the actual prefix)
 	 * @param array $input data that should be inserted into the table  (column name => value)
 	 * @return int number of inserted rows
-	 * @since 17.0.0
+	 * @since 16.0.0
 	 */
-	public function insertIgnoreConflict($table, $input) : int;
+	public function insertIgnoreConflict(string $table,array $values) : int;
 
 	/**
 	 * Insert or update a row value
@@ -128,11 +128,11 @@ interface IDBConnection {
 	 *
 	 * @param string $table The table name (will replace *PREFIX* with the actual prefix)
-	 * @param array $input data that should be inserted into the table  (column name => value)
+	 * @param array $values data that should be inserted into the table  (column name => value)
 	 * @return int number of inserted rows
-- 
cgit v1.2.3